==> nextcloud-27.1.4.tgz: nextcloud/apps/user_status/l10n/is.js <==
OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "Nýlegar stöður",
    "No recent status changes" : "Engar nýlegar breytingar á stöðu",
    "In a meeting" : "Á fundi",
    "Commuting" : "Á ferðinni",
    "Out sick" : "Veikindi",
    "Vacationing" : "Í fríi",
    "Working remotely" : "Fjarvinna",
    "User status" : "Staða notanda",
    "Clear status after" : "Hreinsa stöðu eftir",
    "What is your status?" : "Hver er staðan á þér?",
    "Set status" : "Setja stöðu",
    "Online status" : "Staða á netinu",
    "Status message" : "Stöðuskilaboð",
    "Clear status message" : "Hreinsa stöðuskilaboð",
    "Set status message" : "Setja stöðuskilaboð",
    "There was an error saving the status" : "Það kom upp villa við að vista stöðuna",
    "There was an error clearing the status" : "Það kom upp villa við að hreinsa stöðuna",
    "Don't clear" : "Ekki hreinsa",
    "Today" : "Í dag",
    "This week" : "Í þessari viku",
    "Online" : "Á netinu",
    "Away" : "Fjarverandi",
    "Do not disturb" : "Ónáðið ekki",
    "Invisible" : "Ósýnilegt",
    "Offline" : "Ótengt neti",
    "There was an error saving the new status" : "Það kom upp villa við að vista nýju stöðuna",
    "30 minutes" : "30 mínútur",
    "1 hour" : "1 klukkustund",
    "4 hours" : "4 klukkustundir",
    "Mute all notifications" : "Þagga allar tilkynningar",
    "Appear offline" : "Birtast ótengt",
    "{status}, {timestamp}" : "{status}, {timestamp}"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");

==> nextcloud-27.1.5.tgz: nextcloud/apps/user_status/l10n/is.js <==
OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "Nýlegar stöður",
    "No recent status changes" : "Engar nýlegar breytingar á stöðu",
    "In a meeting" : "Á fundi",
    "Commuting" : "Á ferðinni",
    "Out sick" : "Veikindi",
    "Vacationing" : "Í fríi",
    "Working remotely" : "Fjarvinna",
    "In a call" : "Er í símtali",
    "User status" : "Staða notanda",
    "Clear status after" : "Hreinsa stöðu eftir",
    "Emoji for your status message" : "Tákn fyrir stöðufærsluna þína",
    "What is your status?" : "Hver er staðan á þér?",
    "Predefined statuses" : "Forákvarðaðar stöður",
    "Previously set" : "Áður stillt",
    "Reset status" : "Endurstilla stöðu",
    "Set status" : "Setja stöðu",
    "Online status" : "Staða á netinu",
    "Status message" : "Stöðuskilaboð",
    "Your status was set automatically" : "Staðan þín var stillt sjálfvirkt",
    "Clear status message" : "Hreinsa stöðuskilaboð",
    "Set status message" : "Setja stöðuskilaboð",
    "Reset status to \"{icon} {message}\"" : "Endurstilla stöðu sem \"{icon} {message}\"",
    "Reset status to \"{message}\"" : "Endurstilla stöðu sem \"{message}\"",
    "Reset status to \"{icon}\"" : "Endurstilla stöðu sem \"{icon}\"",
    "There was an error saving the status" : "Það kom upp villa við að vista stöðuna",
    "There was an error clearing the status" : "Það kom upp villa við að hreinsa stöðuna",
    "There was an error reverting the status" : "Það kom upp villa við að afturkalla stöðuna",
    "Don't clear" : "Ekki hreinsa",
    "Today" : "Í dag",
    "This week" : "Í þessari viku",
    "Online" : "Á netinu",
    "Away" : "Fjarverandi",
    "Do not disturb" : "Ónáðið ekki",
    "Invisible" : "Ósýnilegt",
    "Offline" : "Ótengdur neti",
    "There was an error saving the new status" : "Það kom upp villa við að vista nýju stöðuna",
    "30 minutes" : "30 mínútur",
    "1 hour" : "1 klukkustund",
    "4 hours" : "4 klukkustundir",
    "Mute all notifications" : "Þagga allar tilkynningar",
    "Appear offline" : "Birtast ótengt",
    "View profile" : "Skoða notandasnið",
    "{status}, {timestamp}" : "{status}, {timestamp}"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
